@@ -12,19 +12,22 @@ class GeneratorConfig(BaseModel):
     object_bases: List[str] = ["turms.types.object.GraphQLObject"]
     interface_bases: List[str] = ["turms.types.object.GraphQLObject"]
 
-    scalar_definitions = {
-        "ID": "str",
-        "String": "str",
-        "Int": "int",
-        "Boolean": "bool",
-        "GenericScalar": "Dict",
-        "DateTime": "str",
-    }
+    scalar_definitions = {}
 
     additional_bases = {}
     extensions: Dict = {}
 
+    prepend_fragment: str = ""
+    append_fragment: str = "Fragment"
+    prepend_query: str = ""
+    append_query: str = "Query"
+    prepend_mutation: str = ""
+    append_mutation: str = "Mutation"
+    prepend_subscription: str = ""
+    append_subscription: str = "Subscription"
+
 
 class GraphQLConfig(BaseModel):
     schema_url: Optional[AnyHttpUrl] = Field(alias="schema")
     documents: Optional[str]
+    domain: str = "default"
